@@ -7,18 +7,19 @@ from spackle.constants import FEATURE_TYPE_FLAG, FEATURE_TYPE_LIMIT
 api_key = None
 api_base = "https://api.spackle.so/v1"
 schema_version = 1
-
-_thread = threading.local()
+_store = None
 
 
 def get_store():
-    if not hasattr(_thread, "store"):
-        _thread.store = DynamoDBStore()
-    return _thread.store
+    global _store
+    if not _store:
+        _store = DynamoDBStore()
+    return _store
 
 
 def set_store(store):
-    _thread.store = store
+    global _store
+    _store = store
 
 
 def bootstrap():
